Peripheral access API for ATSAML22J18A microcontrollers (generated using svd2rust v0.34.0 ( ))
You can find an overview of the generated API here.
API features to be included in the next
svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.
Re-exports
pub use self::port as port_iobus;pub use self::sercom0 as sercom1;pub use self::sercom0 as sercom2;pub use self::sercom0 as sercom3;pub use self::tc0 as tc1;pub use self::tc0 as tc2;pub use self::tc0 as tc3;
Modules
- ac
- Analog Comparators
- adc
- Analog Digital Converter
- aes
- Advanced Encryption Standard
- ccl
- Configurable Custom Logic
- dmac
- Direct Memory Access Controller
- dsu
- Device Service Unit
- eic
- External Interrupt Controller
- evsys
- Event System Interface
- freqm
- Frequency Meter
- gclk
- Generic Clock Generator
- generic
- Common register and bit access and modify traits
- mclk
- Main Clock
- mtb
- Cortex-M0+ Micro-Trace Buffer
- nvmctrl
- Non-Volatile Memory Controller
- osc32kctrl
- 32k Oscillators Control
- oscctrl
- Oscillators Control
- pac
- Peripheral Access Controller
- pm
- Power Manager
- port
- Port Module
- rstc
- Reset Controller
- rtc
- Real-Time Counter
- sercom0
- Serial Communication Interface 0
- slcd
- Segment Liquid Crystal Display Controller
- supc
- Supply Controller
- tc0
- Basic Timer Counter 0
- tcc0
- Timer Counter Control
- trng
- True Random Generator
- usb
- Universal Serial Bus
- wdt
- Watchdog Timer
Structs
- Ac
- Analog Comparators
- Adc
- Analog Digital Converter
- Aes
- Advanced Encryption Standard
- Ccl
- Configurable Custom Logic
- Dmac
- Direct Memory Access Controller
- Dsu
- Device Service Unit
- Eic
- External Interrupt Controller
- Evsys
- Event System Interface
- Freqm
- Frequency Meter
- Gclk
- Generic Clock Generator
- Mclk
- Main Clock
- Mtb
- Cortex-M0+ Micro-Trace Buffer
- Nvmctrl
- Non-Volatile Memory Controller
- Osc32kctrl
- 32k Oscillators Control
- Oscctrl
- Oscillators Control
- Pac
- Peripheral Access Controller
- Peripherals
- All the peripherals.
- Pm
- Power Manager
- Port
- Port Module
- Port
Iobus - Port Module (IOBUS)
- Rstc
- Reset Controller
- Rtc
- Real-Time Counter
- Sercom0
- Serial Communication Interface 0
- Sercom1
- Serial Communication Interface 1
- Sercom2
- Serial Communication Interface 2
- Sercom3
- Serial Communication Interface 3
- Slcd
- Segment Liquid Crystal Display Controller
- Supc
- Supply Controller
- Tc0
- Basic Timer Counter 0
- Tc1
- Basic Timer Counter 1
- Tc2
- Basic Timer Counter 2
- Tc3
- Basic Timer Counter 3
- Tcc0
- Timer Counter Control
- Trng
- True Random Generator
- Usb
- Universal Serial Bus
- Wdt
- Watchdog Timer
Enums
- Interrupt
- Enumeration of all the interrupts.
Constants
- NVIC_
PRIO_ BITS - Number available in the NVIC for configuring priority